==> unity-ads-4.9.2-sources.jar: com/unity3d/ads/core/domain/GetAndroidUniversalRequestSharedData.kt <==
package com.unity3d.ads.core.domain

import com.unity3d.ads.core.data.repository.DeveloperConsentRepository
import com.unity3d.ads.core.data.repository.DeviceInfoRepository
import com.unity3d.ads.core.data.repository.SessionRepository
import com.unity3d.ads.core.extensions.fromMillis
import com.unity3d.services.core.properties.SdkProperties
import gateway.v1.UniversalRequestKt.sharedData
import gateway.v1.UniversalRequestOuterClass.UniversalRequest.SharedData

internal class GetAndroidUniversalRequestSharedData(
    private val getSharedDataTimestamps: GetSharedDataTimestamps,
    private val sessionRepository: SessionRepository,
    private val deviceInfoRepository: DeviceInfoRepository,
    private val developerConsentRepository: DeveloperConsentRepository
) : GetUniversalRequestSharedData {
    override suspend fun invoke(): SharedData {
        return sharedData {
            val sToken = sessionRepository.sessionToken
            if (!sToken.isEmpty) sessionToken = sToken
            timestamps = getSharedDataTimestamps()
            // UTC timestamp when application called initialize method in milliseconds
            sdkStartTime = fromMillis(SdkProperties.getInitializationTimeEpoch())
            // UTC timestamp when application started in milliseconds
            appStartTime = fromMillis(SdkProperties.getAppInitializationTimeSinceEpoch())
            developerConsent = developerConsentRepository.developerConsent
            pii = deviceInfoRepository.piiData
        }
    }
}

==> unity-ads-4.10.0-sources.jar: com/unity3d/ads/core/domain/GetAndroidUniversalRequestSharedData.kt <==
package com.unity3d.ads.core.domain

import com.unity3d.ads.core.data.repository.DeveloperConsentRepository
import com.unity3d.ads.core.data.repository.DeviceInfoRepository
import com.unity3d.ads.core.data.repository.SessionRepository
import com.unity3d.ads.core.extensions.fromMillis
import com.unity3d.services.core.properties.SdkProperties
import gateway.v1.UniversalRequestKt.sharedData
import gateway.v1.UniversalRequestOuterClass.UniversalRequest.SharedData

internal class GetAndroidUniversalRequestSharedData(
    private val getSharedDataTimestamps: GetSharedDataTimestamps,
    private val sessionRepository: SessionRepository,
    private val deviceInfoRepository: DeviceInfoRepository,
    private val developerConsentRepository: DeveloperConsentRepository
) : GetUniversalRequestSharedData {
    override suspend fun invoke(): SharedData {
        return sharedData {
            val sToken = sessionRepository.sessionToken
            if (!sToken.isEmpty) sessionToken = sToken
            timestamps = getSharedDataTimestamps()
            // UTC timestamp when application called initialize method in milliseconds
            sdkStartTime = fromMillis(SdkProperties.getInitializationTimeEpoch())
            // UTC timestamp when application started in milliseconds
            appStartTime = fromMillis(SdkProperties.getAppInitializationTimeSinceEpoch())
            developerConsent = developerConsentRepository.developerConsent
            val piiData = deviceInfoRepository.piiData
            if (!piiData.advertisingId.isEmpty || !piiData.openAdvertisingTrackingId.isEmpty) pii = piiData
        }
    }
}
